==> ejc-middlemeasurement-impl-3.0.0-20220412.090131-33-sources.jar: com/ejianc/business/middlemeasurement/vo/PurchasesummarydetatilVO.java <==
package com.ejianc.business.middlemeasurement.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 月度物资采购结算汇总子表
 * 
 * @author generator
 * 
 */
public class PurchasesummarydetatilVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.String sotr; // 序号
    private java.lang.String contractName; // 合同名称
    private java.lang.String categoryCode; // 类别编号
    private java.lang.String materialCategory; // 物资类别名称
    private java.lang.String supplierName; // 供应商名称
    private java.math.BigDecimal settlementAmount; // 本月结算金额(除税)
    private java.math.BigDecimal taxSettlementAmount; // 本月结算金额(含税)
    private java.math.BigDecimal settlementTotal; // 累计结算金额(除税)
    private java.math.BigDecimal taxSettlementTotal; // 累计结算金额(含税)
    private java.math.BigDecimal paymentProportion; // 合同付款比例
    private java.math.BigDecimal cumulativePayable; // 至本月累计应付款金额
    private java.math.BigDecimal cumulativePayment; // 至本月累计付款金额
    private java.lang.String contacts; // 联系人
    private java.lang.String contactsWay; // 联系方式
    private java.lang.String remarks; // 备注
    private java.lang.Long mid; // 主表id
    

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSotr() {
        return sotr;
    }

    /**
     * 序号
     */
    public void setSotr(java.lang.String sotr) {
        this.sotr = sotr;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 类别编号
     */
    public java.lang.String getCategoryCode() {
        return categoryCode;
    }

    /**
     * 类别编号
     */
    public void setCategoryCode(java.lang.String categoryCode) {
        this.categoryCode = categoryCode;
    }
    /**
     * 物资类别名称
     */
    public java.lang.String getMaterialCategory() {
        return materialCategory;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialCategory(java.lang.String materialCategory) {
        this.materialCategory = materialCategory;
    }
    /**
     * 供应商名称
     */
    public java.lang.String getSupplierName() {
        return supplierName;
    }

    /**
     * 供应商名称
     */
    public void setSupplierName(java.lang.String supplierName) {
        this.supplierName = supplierName;
    }
    /**
     * 本月结算金额(除税)
     */
    public java.math.BigDecimal getSettlementAmount() {
        return settlementAmount;
    }

    /**
     * 本月结算金额(除税)
     */
    public void setSettlementAmount(java.math.BigDecimal settlementAmount) {
        this.settlementAmount = settlementAmount;
    }
    /**
     * 本月结算金额(含税)
     */
    public java.math.BigDecimal getTaxSettlementAmount() {
        return taxSettlementAmount;
    }

    /**
     * 本月结算金额(含税)
     */
    public void setTaxSettlementAmount(java.math.BigDecimal taxSettlementAmount) {
        this.taxSettlementAmount = taxSettlementAmount;
    }
    /**
     * 累计结算金额(除税)
     */
    public java.math.BigDecimal getSettlementTotal() {
        return settlementTotal;
    }

    /**
     * 累计结算金额(除税)
     */
    public void setSettlementTotal(java.math.BigDecimal settlementTotal) {
        this.settlementTotal = settlementTotal;
    }
    /**
     * 累计结算金额(含税)
     */
    public java.math.BigDecimal getTaxSettlementTotal() {
        return taxSettlementTotal;
    }

    /**
     * 累计结算金额(含税)
     */
    public void setTaxSettlementTotal(java.math.BigDecimal taxSettlementTotal) {
        this.taxSettlementTotal = taxSettlementTotal;
    }
    /**
     * 合同付款比例
     */
    public java.math.BigDecimal getPaymentProportion() {
        return paymentProportion;
    }

    /**
     * 合同付款比例
     */
    public void setPaymentProportion(java.math.BigDecimal paymentProportion) {
        this.paymentProportion = paymentProportion;
    }
    /**
     * 至本月累计应付款金额
     */
    public java.math.BigDecimal getCumulativePayable() {
        return cumulativePayable;
    }

    /**
     * 至本月累计应付款金额
     */
    public void setCumulativePayable(java.math.BigDecimal cumulativePayable) {
        this.cumulativePayable = cumulativePayable;
    }
    /**
     * 至本月累计付款金额
     */
    public java.math.BigDecimal getCumulativePayment() {
        return cumulativePayment;
    }

    /**
     * 至本月累计付款金额
     */
    public void setCumulativePayment(java.math.BigDecimal cumulativePayment) {
        this.cumulativePayment = cumulativePayment;
    }
    /**
     * 联系人
     */
    public java.lang.String getContacts() {
        return contacts;
    }

    /**
     * 联系人
     */
    public void setContacts(java.lang.String contacts) {
        this.contacts = contacts;
    }
    /**
     * 联系方式
     */
    public java.lang.String getContactsWay() {
        return contactsWay;
    }

    /**
     * 联系方式
     */
    public void setContactsWay(java.lang.String contactsWay) {
        this.contactsWay = contactsWay;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    
}

==> ejc-middlemeasurement-impl-3.0.0-20230329.060407-406-sources.jar: com/ejianc/business/middlemeasurement/vo/PurchasesummarydetatilVO.java <==
package com.ejianc.business.middlemeasurement.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 月度物资采购结算汇总子表
 * 
 * @author generator
 * 
 */
public class PurchasesummarydetatilVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.String sotr; // 序号
    private java.lang.String contractName; // 合同名称
    private java.lang.String categoryCode; // 类别编号
    private java.lang.String materialCategory; // 物资类别名称
    private java.lang.String supplierName; // 供应商名称
    private java.math.BigDecimal settlementAmount; // 本月结算金额(除税)
    private java.math.BigDecimal taxSettlementAmount; // 本月结算金额(含税)
    private java.math.BigDecimal settlementTotal; // 累计结算金额(除税)
    private java.math.BigDecimal taxSettlementTotal; // 累计结算金额(含税)
    private java.math.BigDecimal paymentProportion; // 合同付款比例
    private java.math.BigDecimal cumulativePayable; // 至本月累计应付款金额
    private java.math.BigDecimal cumulativePayment; // 至本月累计付款金额
    private java.lang.String contacts; // 联系人
    private java.lang.String contactsWay; // 联系方式
    private java.lang.String remarks; // 备注
    private java.lang.Long mid; // 主表id
    private java.lang.String errorMsg;

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSotr() {
        return sotr;
    }

    /**
     * 序号
     */
    public void setSotr(java.lang.String sotr) {
        this.sotr = sotr;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 类别编号
     */
    public java.lang.String getCategoryCode() {
        return categoryCode;
    }

    /**
     * 类别编号
     */
    public void setCategoryCode(java.lang.String categoryCode) {
        this.categoryCode = categoryCode;
    }
    /**
     * 物资类别名称
     */
    public java.lang.String getMaterialCategory() {
        return materialCategory;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialCategory(java.lang.String materialCategory) {
        this.materialCategory = materialCategory;
    }
    /**
     * 供应商名称
     */
    public java.lang.String getSupplierName() {
        return supplierName;
    }

    /**
     * 供应商名称
     */
    public void setSupplierName(java.lang.String supplierName) {
        this.supplierName = supplierName;
    }
    /**
     * 本月结算金额(除税)
     */
    public java.math.BigDecimal getSettlementAmount() {
        return settlementAmount;
    }

    /**
     * 本月结算金额(除税)
     */
    public void setSettlementAmount(java.math.BigDecimal settlementAmount) {
        this.settlementAmount = settlementAmount;
    }
    /**
     * 本月结算金额(含税)
     */
    public java.math.BigDecimal getTaxSettlementAmount() {
        return taxSettlementAmount;
    }

    /**
     * 本月结算金额(含税)
     */
    public void setTaxSettlementAmount(java.math.BigDecimal taxSettlementAmount) {
        this.taxSettlementAmount = taxSettlementAmount;
    }
    /**
     * 累计结算金额(除税)
     */
    public java.math.BigDecimal getSettlementTotal() {
        return settlementTotal;
    }

    /**
     * 累计结算金额(除税)
     */
    public void setSettlementTotal(java.math.BigDecimal settlementTotal) {
        this.settlementTotal = settlementTotal;
    }
    /**
     * 累计结算金额(含税)
     */
    public java.math.BigDecimal getTaxSettlementTotal() {
        return taxSettlementTotal;
    }

    /**
     * 累计结算金额(含税)
     */
    public void setTaxSettlementTotal(java.math.BigDecimal taxSettlementTotal) {
        this.taxSettlementTotal = taxSettlementTotal;
    }
    /**
     * 合同付款比例
     */
    public java.math.BigDecimal getPaymentProportion() {
        return paymentProportion;
    }

    /**
     * 合同付款比例
     */
    public void setPaymentProportion(java.math.BigDecimal paymentProportion) {
        this.paymentProportion = paymentProportion;
    }
    /**
     * 至本月累计应付款金额
     */
    public java.math.BigDecimal getCumulativePayable() {
        return cumulativePayable;
    }

    /**
     * 至本月累计应付款金额
     */
    public void setCumulativePayable(java.math.BigDecimal cumulativePayable) {
        this.cumulativePayable = cumulativePayable;
    }
    /**
     * 至本月累计付款金额
     */
    public java.math.BigDecimal getCumulativePayment() {
        return cumulativePayment;
    }

    /**
     * 至本月累计付款金额
     */
    public void setCumulativePayment(java.math.BigDecimal cumulativePayment) {
        this.cumulativePayment = cumulativePayment;
    }
    /**
     * 联系人
     */
    public java.lang.String getContacts() {
        return contacts;
    }

    /**
     * 联系人
     */
    public void setContacts(java.lang.String contacts) {
        this.contacts = contacts;
    }
    /**
     * 联系方式
     */
    public java.lang.String getContactsWay() {
        return contactsWay;
    }

    /**
     * 联系方式
     */
    public void setContactsWay(java.lang.String contactsWay) {
        this.contactsWay = contactsWay;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    
}
